@@ -1001,7 +1001,7 @@ class NumerousClient:
 
         return blocks
 
-    def write_with_row_generator(self, data_generator, scenario: str = None, clear=False, must_flush=None,
+    def write_with_row_generator(self, data_generator, scenario: Optional[str] = None, clear=False, must_flush=None,
                                  execution=None):
         if must_flush is None:
             def must_flush_(_n, _m):
